@@ -32,7 +32,7 @@ def delignore(userhost):
         del ignore.data[userhost]
         ignore.save()
         return 1
-    except:
+    except KeyError:
         return 0
 
 def shouldignore(userhost):
@@ -40,7 +40,7 @@ def shouldignore(userhost):
     try:
         ignoretime = ignore.data[userhost]
         ignoreset = timeset.data[userhost]
-    except:
+    except KeyError:
         return 0
     if time.time() - ignoretime < ignoreset:
         return 1
