@@ -7,8 +7,8 @@
 
 __copyright__ = 'this file is in the public domain'
 
-from gozerbot.generic import rlog, handle_exception, getrandomnick, toascii, \
-fix_format, splittxt, waitforqueue, calledfrom
+from gozerbot.generic import rlog, handle_exception, getrandomnick, todefenc, \
+fix_format, splittxt, waitforqueue
 from gozerbot.wait import Wait
 from gozerbot.config import config
 from gozerbot.ircevent import Ircevent
@@ -18,13 +18,21 @@ from gozerbot.ignore import shouldignore
 from gozerbot.pdod import Pdod
 from gozerbot.datadir import datadir
 from gozerbot.eventhandler import Outputhandler
+from gozerbot.fleet import fleet
+
 import gozerbot.thr as thr
-import time, thread, socket, threading, os, Queue, types, sys
+import time, thread, socket, threading, os, Queue
 
 class AlreadyConnected(Exception):
+
+    """ already connected exception """
+
     pass
 
 class AlreadyConnecting(Exception):
+
+    """ bot is already connecting exception """
+
     pass
 
 class Irc(object):
@@ -41,8 +49,8 @@ class Irc(object):
         self.outputhandler = Outputhandler(self)
         self.fsock = None
         self.sock = None
-        self.nick = 'cb1'
-        self.orignick = self.nick
+        self.nick = config['nick'] or 'gb1'
+        self.orignick = config['orignick'] or self.nick
         self.server = 'localhost'
         self.port = 6667
         self.password = None
@@ -61,6 +69,15 @@ class Irc(object):
             self.state['alternick'] = config['alternick']
         if not self.state.has_key('no-op'):
             self.state['no-op'] = []
+        if not self.state.has_key('nick'):
+            self.state['nick'] = config['nick'] or 'gb1'
+        if not self.state.has_key('confignick'):
+            self.state['confignick'] = config['nick']
+        if config['nick'] != self.state['confignick']:
+            self.state['nick'] = config['nick']
+            self.state['confignick'] = config['nick']
+            self.state.save()
+        self.nick = self.state['nick']
         self.outputhandler.start()
 
     def connect(self, nick, server, port=6667, password=None, ipv6=None, \
@@ -81,6 +98,8 @@ reconnect=True):
             rlog(10, self.name, str(ex))
             if reconnect:
                 return self.reconnect()
+        if not fleet.byname(self.name):
+            fleet.addbot(self)
 
     def doconnect(self, nick, server, port, password, ipv6):
         """ connect to server/port using nick """
@@ -113,6 +132,7 @@ reconnect=True):
         self.sock.connect((self.server, int(self.port)))
         # we are connected
         rlog(10, self.name, 'connection ok')
+        self.stopped = 0
         # make file socket
         self.fsock = self.sock.makefile("r")
         # set blocking
@@ -128,6 +148,7 @@ reconnect=True):
             self.sock.settimeout(socktimeout)
             self.fsock._sock.settimeout(socktimeout)
         # start readloop
+        self.outputhandler.start()
         rlog(0, self.name, 'starting readloop')
         thr.start_new_thread(self.readloop, ())
         # execute onconnect file .. code that can be executed after login
@@ -135,13 +156,13 @@ reconnect=True):
         self.onconnect()
         # init 
         self.reconnectcount = 0
-        self.stopped = 0
         self.nickchanged = 0
         self.outputhandler.nooutput = False
         self.connecting = False
         return 1
 
     def logon(self):
+        """ log on to the network """
         # if password is provided send it
         if self.password:
             rlog(10, self.name ,'sending password')
@@ -154,7 +175,7 @@ reconnect=True):
         username = config['username'] or self.nick
         realname = config['realname'] or username
         # first send nick
-        self.send("NICK %s" % self.orignick)
+        self.send("NICK %s" % self.nick)
         # send USER
         self.send("USER %s localhost localhost :%s" % (username, realname))
         # wait on login
@@ -163,6 +184,7 @@ reconnect=True):
         rlog(10, self.name, 'logged on !')
 
     def onconnect(self):
+        """ run the onconnect-botname file after connect """
         onconnectfile = 'onconnect-%s' % self.name
         try:
             execfile(onconnectfile, globals(), locals())
@@ -174,10 +196,10 @@ reconnect=True):
                     pass
                 else:
                     rlog(5, self.name, 'error excecuting %s: %s' % \
-(onconnect, str(error)))
-            except:
+(onconnectfile, str(error)))
+            except ValueError:
                 rlog(5, self.name, 'error excecuting %s: %s' % \
-(onconnect, str(ex)))
+(onconnectfile, str(ex)))
 
     def readloop(self):
         """ loop on the socketfile """
@@ -187,7 +209,7 @@ reconnect=True):
         while not self.stopped:
             try:
                 time.sleep(0.001)
-                res = toascii(self.fsock.readline())
+                res = todefenc(self.fsock.readline())
                 # if res == "" the other side has disconnected
                 if not res and not self.stopped:
                     doreconnect = 1
@@ -256,23 +278,28 @@ reconnect=True):
         except:
             pass
         try:
+            time.sleep(1)
             self.sock.close()
             self.fsock.close()
         except:
             pass
         self.connecting = False
-        
+        self.connectok.clear()
+
     def exit(self):
+        """ exit the bot """
+        self.stopped = 1
         self.outputhandler.stop()
+        self.shutdown()
 
     def reconnect(self):
         """ reconnect to the irc server """
         if self.stopped:
             return 0
         self.shutdown()
-        time.sleep(5)
-        self.stopped = 0
         rlog(10, self.name, 'reconnecting')
+        self.stopped = 0
+        time.sleep(5)
         # determine how many seconds to sleep
         if self.reconnectcount > 0:
             reconsleep = self.reconnectcount*60
@@ -281,7 +308,7 @@ reconnect=True):
         if self.stopped:
             return 0
         self.reconnectcount += 1
-        return self.connect(self.orignick, self.server, self.port, \
+        return self.connect(self.nick, self.server, self.port, \
 self.password, self.ipv6)
 
     def handle_pong(self, ievent):
@@ -294,7 +321,10 @@ self.password, self.ipv6)
         if not txt:
             return
         rlog(2, self.name + '.sending', txt)
-        self.sock.send(txt+'\n')
+        try:
+            self.sock.send(txt + '\n')
+        except Exception, ex:
+            rlog(10, self.name, "ERROR: can't send %s" % str(ex))
 
     def fakein(self, txt):
         """ do a fake ircevent """
@@ -323,7 +353,7 @@ self.password, self.ipv6)
         """ output the first 375 chars .. put the rest into cache """
         # first do mombo to get txt converted to ascii
         try:
-            what = toascii(what.rstrip())
+            what = todefenc(what.rstrip())
         except Exception, ex:
             rlog(10, self.name, "can't output: %s" % str(ex))
             return
@@ -381,17 +411,20 @@ self.password, self.ipv6)
             return
         self.noauto433 = 1
         queue = Queue.Queue()
-        self.wait.register('433', self.nick, queue, 5)
+        self.wait.register('NICK', self.nick, queue, 5)
         self.send('NICK %s' % nick)
-        result = queue.get()
+        result = waitforqueue(queue)
         self.noauto433 = 0
-        if result:
+        if not result:
             return 0
         self.nick = nick
         if setorig:
             self.orignick = nick
         if save:
-            config.set('nick', nick)
+            self.state['nick'] = nick
+            self.state.save()
+            if fleet.getmainbot() == self:
+                config.set('nick', nick)
         return 1
 
     def join(self, channel, password=None):
@@ -399,14 +432,14 @@ self.password, self.ipv6)
         if not channel:
             return
         q = Queue.Queue()
-        self.wait.register('437', channel, q, 3)
+        self.wait.register('353', channel, q, 5)
         if password:
             self.send('JOIN %s %s' % (channel, password))
         else:
             self.send('JOIN %s' % channel)
-        result = waitforqueue(q, 3)
-        if result:
-            return result[0].txt
+        result = waitforqueue(q, 5)
+        if not result:
+            return 'failed to join %s' % channel
         else:
             return 1
 
@@ -414,7 +447,14 @@ self.password, self.ipv6)
         """ leave channel """
         if not channel:
             return
+        q = Queue.Queue()
+        self.wait.register('PART', channel, q, 5)
         self.send('PART %s' % channel)
+        result = waitforqueue(q, 5)
+        if not result:
+            return 0
+        else:
+            return 1
 
     def who(self, who):
         """ send who query """
@@ -483,7 +523,7 @@ self.password, self.ipv6)
         rlog(10, self.name, 'sending quit')
         try:
             self.sock.send('QUIT :%s\n' % reason)
-        except:
+        except IOError:
             pass
 
     def notice(self, printto, what):
@@ -528,6 +568,7 @@ self.password, self.ipv6)
             self.wait.check(ievent)
         except:
             handle_exception()
+
     def handle_433(self, ievent):
         """ handle nick already taken """
         if self.noauto433:
@@ -543,6 +584,7 @@ self.password, self.ipv6)
         # use random nick
         randomnick = getrandomnick()
         self.donick(randomnick)
+        self.nick = randomnick
         rlog(100, self.name, 'ALERT: nick %s already in use/unavailable .. \
 using randomnick %s' % (nick, randomnick))
         self.nickchanged = 1
@@ -580,7 +622,7 @@ using randomnick %s' % (nick, randomnick))
                 if pingtime:
                     self.ctcpreply(ievent.nick, 'PING ' + pingtime + ' ' + \
 pingtime2)
-            except:
+            except IndexError:
                 pass
 
     def handle_error(self, ievent):
