@@ -6,11 +6,11 @@
 
 __copyright__ = 'this file is in the public domain'
 
-from gozerbot.generic import getwho, stripident, handle_exception
+from gozerbot.generic import getwho, stripident
 from gozerbot.users import users
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
-from gozerbot.aliases import aliases
+from gozerbot.aliases import aliases, aliasdel
 from gozerbot.plughelp import plughelp
 
 plughelp.add('user', 'manage users')
@@ -85,6 +85,13 @@ def handle_merge(bot, ievent):
         return  
     name, nick = ievent.args
     name = name.lower()
+    if users.gotperm(name, 'OPER') and not users.allowed(ievent.userhost, \
+'OPER'):
+        ievent.reply("only OPER perm can merge with OPER user")
+        return
+    if name == 'owner' and ievent.userhost != bot.owner:     
+         ievent.reply('only owneruserhost can merge with owner user') 
+         return 
     if not users.exist(name):
         ievent.reply("we have no user %s" % name)
         return
@@ -108,7 +115,7 @@ def handle_merge(bot, ievent):
     else:
         ievent.reply('merge failed')
 
-cmnds.add('user-merge', handle_merge, 'OPER')
+cmnds.add('user-merge', handle_merge, ['OPER', 'MEET'])
 examples.add('user-merge', 'user-merge <name> <nick> .. merge record with \
 <name> with userhost from <nick>', 'merge bart dunker')
 aliases.data['merge'] = 'user-merge'
@@ -604,7 +611,7 @@ def handle_addpermit(bot, ievent):
         of <name> """
     try:
         who, what = ievent.args
-    except:
+    except ValueError:
         ievent.missing("<name> <what>")
         return
     if not users.exist(who):
@@ -630,7 +637,7 @@ cmnds.add('user-addpermit', handle_addpermit, 'USER')
 examples.add('user-addpermit', 'user-addpermit <nick> <what> .. permit \
 nick access to <what> .. use setperms to add permissions', \
 'user-addpermit dunker todo')
-aliases.data['allow'] = 'user-addpermit'
+aliasdel('allow')
 
 def handle_permit(bot, ievent):
     """ user-permit .. get permit list of user giving the command """
@@ -663,7 +670,7 @@ def handle_userdelpermit(bot, ievent):
         list """
     try:
         who, what = ievent.args
-    except:
+    except ValueError:
         ievent.missing("<name> <what>")
         return
     if not users.exist(who):
@@ -688,7 +695,7 @@ name = %s AND permit = %s """, (name, "%s %s" % (who, what)))
 cmnds.add('user-delpermit', handle_userdelpermit, 'USER')
 examples.add('user-delpermit', 'user-delpermit <name> <permit>', \
 'user-delpermit dunker todo')
-aliases.data['deny'] = 'user-delpermit'
+aliasdel('deny')
 
 def handle_check(bot, ievent):
     """ user-check <nick> .. get user data of <nick> """
@@ -717,9 +724,9 @@ WHERE name = %s """, name)
 WHERE name = %s """, name)
     jarig = users.db.execute(""" SELECT birthday FROM birthday \
 WHERE name = %s """, name)
-    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s permits: %s \
-status: %s birthday: %s' % (name, str(userhosts), str(perms), str(email), \
-str(permits), str(status),str(jarig)))
+    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s \
+permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), \
+str(email), str(permits), str(status),str(jarig)))
 
 cmnds.add('user-check', handle_check, 'OPER')
 examples.add('user-check', 'user-check <nick>', 'user-check dunker')
@@ -748,9 +755,9 @@ WHERE name = %s """, name)
 WHERE name = %s """, name)
     jarig = users.db.execute(""" SELECT birthday FROM birthday \
 WHERE name = %s """, name)
-    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s permits: %s \
-status: %s birthday: %s' % (name, str(userhosts), str(perms), str(email), \
-str(permits), str(status),str(jarig)))
+    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s \
+permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), \
+str(email), str(permits), str(status),str(jarig)))
 
 cmnds.add('user-show', handle_show, 'OPER')
 examples.add('user-show', 'user-show <name> .. show data of <name>', \
@@ -779,9 +786,9 @@ WHERE name = %s """, name)
 WHERE name = %s """, name)
     jarig = users.db.execute(""" SELECT birthday FROM birthday \
 WHERE name = %s """, name)
-    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s permits: %s \
-status: %s birthday: %s' % (name, str(userhosts), str(perms), str(email), \
-str(permits), str(status),str(jarig)))
+    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s \
+permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), \
+str(email), str(permits), str(status),str(jarig)))
 
 cmnds.add('user-match', handle_match, ['USER', 'OPER'])
 examples.add('user-match', 'user-match <userhost>', 'user-match test@test')
@@ -836,6 +843,7 @@ examples.add('user-allperm', 'user-allperm <perm> .. get users with \
 <perm> permission', 'user-allperm rss')
 
 def handle_usersearch(bot, ievent):
+    """ search for user matching given userhost """
     try:
         what = ievent.args[0]
     except IndexError:
