@@ -2,14 +2,20 @@
 #
 #
 
+""" make a random choice """
+
 __copyright__ = 'this file is in the public domain'
 
 from gozerbot.generic import waitforqueue
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
+from gozerbot.plughelp import plughelp
 import random
 
+plughelp.add('choice', 'make a random choice of string or pipeline')
+
 def handle_choice(bot, ievent):
+    """ make a random choice out of different words or list elements """ 
     result = []
     if ievent.inqueue:
         result = waitforqueue(ievent.inqueue, 5)
@@ -21,5 +27,5 @@ def handle_choice(bot, ievent):
     ievent.reply(random.choice(result))
 
 cmnds.add('choice', handle_choice, ['USER', 'WEB', 'ANON'])
-examples.add('choice', 'make a random choice', '1) choice a b c 2) todo | \
+examples.add('choice', 'make a random choice', '1) choice a b c 2) list | \
 choice')
