@@ -12,14 +12,20 @@ from gozerbot.examples import examples
 from gozerbot.generic import exceptionlist
 from gozerbot.plugins import plugins
 from gozerbot.aliases import aliasset
-import os
+from gozerbot.plughelp import plughelp
+
+plughelp.add('code', 'the code plugin provides code related commands')
 
 def handle_showexceptions(bot, ievent):
+    """ show exception list """
     ievent.reply(str(exceptionlist))
 
 cmnds.add('code-exceptions' , handle_showexceptions, 'OPER')
+examples.add('code-exceptions', 'show exception list', 'code-exceptions')
+aliasset('exceptions', 'code-exceptions')
 
 def handle_funcnames(bot, ievent):
+    """ show function names of a plugin """
     try:
         plugname = ievent.args[0]
     except IndexError:
@@ -38,4 +44,6 @@ def handle_funcnames(bot, ievent):
         ievent.reply("can't find funcnames for %s plugin" % plugname)
         
 cmnds.add('code-funcnames', handle_funcnames, 'OPER')
+examples.add('code-funcnames', 'show function names of a plugin', \
+'code-funcnames birthday')
 aliasset('funcnames', 'code-funcnames')
