@@ -6,8 +6,7 @@
 
 __copyright__ = 'this file is in the public domain'
 
-from gozerbot.generic import rlog, geturl, handle_exception, toascii, \
-waitforqueue
+from gozerbot.generic import rlog, geturl, todefenc, waitforqueue, strippedtxt
 from gozerbot.rsslist import rsslist
 from gozerbot.datadir import datadir
 from gozerbot.persist import Persist
@@ -50,14 +49,16 @@ def init():
         return 1
     #start_new_thread(boot, ())
     activechecker = Activechecker()
-    start_new_thread(activechecker.checkone,())
+    start_new_thread(activechecker.checkone, ())
     return 1
 
 def shutdown():
+    """ shutdown the collective plugin """
     if activechecker:
         activechecker.stop = 1
 
 def size():
+    """ return number of active collective nodes """
     return len(coll.data['active'])
 
 class Activechecker(object):
@@ -70,6 +71,7 @@ class Activechecker(object):
         rlog(10, 'collective', 'active checker started')
         
     def checker(self):
+        """ active checker loop """
         while not self.stop:
             time.sleep(900)
             if self.stop:
@@ -78,6 +80,7 @@ class Activechecker(object):
         rlog(10, 'collective', 'stopping activechecker')
 
     def checkone(self):
+        """ do one active check """
         removed = []
         added = []
         q = Queue.Queue()
@@ -102,6 +105,7 @@ class Activechecker(object):
         return (removed, added)
 
 def doping(node):
+    """ do ping of a collective node """
     q = Queue.Queue()
     start_new_thread(gotpong, (node, q))
     return waitforqueue(q, 4)
@@ -189,6 +193,8 @@ def colldispatchone(node, what, queue):
 
 def colldispatch(node, what, queue):
     """ dispatch command on remote node .. place result in queue """
+    if what.startswith('coll'):
+        return
     try:
         what = re.sub('\s+', '+', what)
         result = geturl('http://%s/dispatch?%s&how=direct' % (node, what))
@@ -252,6 +258,7 @@ def nodesxml():
     return ""
 
 def handle_collping(bot, ievent):
+    """ do a ping on a collective node """
     if not coll.data['enable']:
         ievent.reply('collective is not enabled')
         return
@@ -353,7 +360,7 @@ def handle_coll(bot, ievent):
             break
         if not res:
             break
-        data = toascii(unescape(res[1]))
+        data = todefenc(strippedtxt(unescape(res[1])))
         got.add(data, res[0])
         teller += 1
     for i, j  in got.iteritems():
@@ -413,7 +420,8 @@ def handle_collexec(bot, ievent):
             break
         if not res:
             break
-        resultstr = "-||%s||- %s " % (name, toascii(unescape(res[1])))
+        resultstr = "-||%s||- %s " % (name, \
+todefenc(strippedtxt(unescape(res[1]))))
     if resultstr:
         ievent.reply("(%s) %s" % (time.time()-starttime, resultstr))
     else:
@@ -473,15 +481,15 @@ def handle_colldelnode(bot, ievent):
     for i in whattodel:
         try:
             coll.data['nodes'].remove(i)
-        except:
+        except ValueError:
             pass
         try:
             del coll.data['names'][i]
-        except:
+        except ValueError:
             pass
         try:
             coll.data['active'].remove(i)
-        except:
+        except ValueError:
             pass
     coll.save()
     ievent.reply('%s deleted' % what)
@@ -500,7 +508,7 @@ def handle_collgetnode(bot, ievent):
     except IndexError:
         ievent.missing('<name>')
         return
-    for i,j in coll.data['names'].iteritems():
+    for i, j in coll.data['names'].iteritems():
         if j == name:
             ievent.reply(i)
             return
@@ -546,7 +554,7 @@ def handle_collboot(bot, ievent):
         return
     try:
         server = ievent.args[0]
-    except:
+    except IndexError:
         server = 'r8.cg.nu:8088'
     bootnr = boot(server)
     if bootnr:
@@ -651,6 +659,7 @@ cmnds.add('coll-checkactive', handle_collcheckactive, 'OPER')
 examples.add('coll-checkactive', 'run active nodes check', 'coll-checkactive')
 
 def handle_collstatus(bot, ievent):
+    """ show active collective nodes """
     if not coll.data['enable']:
         ievent.reply('collective is not enabled')
         return
@@ -671,6 +680,7 @@ cmnds.add('coll-status', handle_collstatus, 'OPER')
 examples.add('coll-status', 'show active  nodes', 'coll-status')
 
 def handle_collrename(bot, ievent):
+    """ rename a collective node """
     if not coll.data['enable']:
         ievent.reply('collective is not enabled')
         return
@@ -695,6 +705,7 @@ examples.add('coll-rename', 'rename a collective node name', \
 'coll-rename dunk dunker')
 
 def handle_collremove(bot, ievent):
+    """ remove a collective node """
     try:
         name = ievent.args[0]
     except IndexError:
