@@ -7,14 +7,14 @@
 __copyright__ = 'this file is in the public domain'
 
 from gozerbot.generic import rlog, handle_exception, elapsedstring, dmy, \
-hourmin, toascii, lockdec
+hourmin, todefenc, lockdec, strtotime
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
 from gozerbot.callbacks import callbacks, jcallbacks
-from gozerbot.aliases import aliases
 from gozerbot.plughelp import plughelp
 from gozerbot.monitor import saymonitor, jabbermonitor
-from gozerbot.aliases import aliases
+from gozerbot.aliases import aliases, aliasdel
+from gozerbot.users import users
 import glob, re, thread, pickle, os, mmap, time
 
 plughelp.add('log', 'logs related commands')
@@ -88,7 +88,7 @@ class Logs(object):
         try:
             size = os.stat(self.filenames[chan])[6]
             return size
-        except:
+        except IOError:
             return
 
     def add(self, channel):
@@ -114,6 +114,7 @@ class Logs(object):
             return 0
 
     def logbot(self, name, ttime, channel, txt):
+        """ log stuff spoken by the bot """
         if channel not in self.loglist:
             rlog(1, 'logs', "%s not in loglist" % channel)
             return
@@ -187,6 +188,7 @@ ievent.txt, filename))
             self.lock.release()
 
     def getmmap(self, channel):
+        """ get an mmap of a channel """
         if channel[0] in ['#', '!', '&', '+']:
             chan = channel[1:].lower()
         else:
@@ -208,6 +210,7 @@ access=mmap.ACCESS_READ)
         return logmap
 
     def loop(self, logmap, nrtimes, func, withbot=False, withcmnd=False):
+        """ loop over the logmap """
         logmap.seek(0)
         teller = 0
         times = 0
@@ -216,14 +219,14 @@ access=mmap.ACCESS_READ)
             if teller % 100000 == 0:
                 time.sleep(0.0001)
             #time.sleep(0.000001)
-            line = toascii(logmap.readline())
+            line = todefenc(logmap.readline())
             if not line:
                 break
             # data is comma seperated
             try:
                 (botname, ttime, nick, userhost, txt) = \
 line.strip().split(',', 4)
-            except:
+            except ValueError:
                 continue
             if not withbot and userhost == 'bot@bot':
                 continue
@@ -232,9 +235,9 @@ line.strip().split(',', 4)
                 continue
             res = func(botname, ttime, nick, userhost, txt)
             if res:
-               times += 1
-               if nrtimes and times > nrtimes:
-                   break
+                times += 1
+                if nrtimes and times > nrtimes:
+                    break
         logmap.close()
 
     def search(self, channel, what, nrtimes):
@@ -247,9 +250,10 @@ line.strip().split(',', 4)
         nrtimes = int(nrtimes)
         logmap = self.getmmap(channel)
         if not logmap:
-             return
+            return
         res = []
         def dofunc(botname, ttime, nick, userhost, txt):
+            """ search log line for matching txt """
             for j in ands:
                 if txt.find(j.strip()) == -1:
                     return
@@ -270,10 +274,12 @@ line.strip().split(',', 4)
             who = who.replace('*', '.*')
             rewho = re.compile(who)
             def dofunc(botname, ttime, nick, userhost, txt):
+                """ add line that matches mask """
                 if re.match(rewho, nick.lower()):
                     result.append((botname, ttime, nick, userhost, txt))
         else:
             def dofunc(botname, ttime, nick, userhost, txt):
+                """ add line that matches nick """
                 if nick.lower() == who:
                     result.append((botname, ttime, nick, userhost, txt))
         self.loop(logmap, None, dofunc)
@@ -292,6 +298,7 @@ line.strip().split(',', 4)
         if not logmap:
             return
         def dofunc(botname, ttime, nick, userhost, txt):
+            """ add line that matches """
             for j in ands:
                 if txt.find(j.strip()) == -1:
                     return
@@ -316,6 +323,7 @@ line.strip().split(',', 4)
         if not logmap:
             return
         def dofunc(botname, ttime, nick, userhost, txt):
+            """ add line that is older then given time """
             logtime = float(ttime)
             if logtime > ftime:
                 res.append((botname, ttime, nick, userhost, txt))
@@ -331,6 +339,7 @@ line.strip().split(',', 4)
         if not logmap:
             return
         def dofunc(botname, ttime, nick, userhost, txt):
+            """ add line that is older then given time including bot outout """
             logtime = float(ttime)
             if logtime > ftime:
                 res.append((botname, ttime, nick, userhost, txt))
@@ -347,6 +356,7 @@ line.strip().split(',', 4)
         if not logmap:
             return
         def dofunc(botname, ttime, nick, userhost, txt):
+            """ add line """
             result.append((botname, ttime, nick, userhost, txt))
             return 1
         self.loop(logmap, None, dofunc)
@@ -365,6 +375,7 @@ line.strip().split(',', 4)
         if not logmap:
             return
         def dofunc(botname, ttime, nick, userhost, txt):
+            """ add line said by nick """
             if nick.lower() == who.lower():
                 result.insert(0, (botname, ttime, nick, userhost, txt))
                 return 1
@@ -384,6 +395,7 @@ line.strip().split(',', 4)
         if not logmap:
             return
         def dofunc(botname, ttime, nick, userhost, txt):
+            """ add line that is said by nick containing txt """
             if nick.lower() == who.lower():
                 got = 0
                 for j in ands:
@@ -409,6 +421,7 @@ line.strip().split(',', 4)
         if not logmap:
             return
         def dofunc(botname, ttime, nick, uh, txt):
+            """ add line that matches userhost """
             if userhost == uh:
                 result.append(int(float(ttime)))
         self.loop(logmap, None, dofunc)
@@ -424,6 +437,7 @@ line.strip().split(',', 4)
         if not logmap:
             return
         def dofunc(botname, ttime, nick, uh, txt):
+            """ add line that matches userhost """
             if userhost == uh:
                 result.append(int(float(ttime)))
         self.loop(logmap, None, dofunc)
@@ -439,8 +453,8 @@ line.strip().split(',', 4)
             return
         result = []
         def dofunc(botname, ttime, nick, userhost, txt):
-            if nick.lower() == who.lower():
-                result.append(nick)
+            """ add nicks  """
+            result.append(nick)
         self.loop(logmap, None, dofunc)
         if len(result) > nrtimes:
             result = result[len(result)-nrtimes:]
@@ -454,15 +468,18 @@ logs = Logs('logs')
 savelist.append(logs)
 
 def prelogsay(botname, printto, txt, who, how, fromm):
+    """ determine if logsay callback needs to be called """
     if printto in logs.loglist:
         return 1
 
 def cblogsay(botname, printto, txt, who, how, fromm):
+    """ log the bots output """
     logs.logbot(botname, time.time(), printto, txt)
 
 saymonitor.add('log', cblogsay, prelogsay)
 
 def jprelogsay(botname, msg):
+    """ jabber log precondition """
     try:
         to = str(msg.getTo())
     except:
@@ -471,6 +488,7 @@ def jprelogsay(botname, msg):
         return 1
 
 def jcblogsay(botname, msg):
+    """ log the jabber message """
     try:
         to = str(msg.getTo())
         txt = msg.getBody()
@@ -553,7 +571,7 @@ def sayresult(bot, ievent, result):
                     what = i[4].split(':', 1)[1].strip()
                 else:
                     what = i[4].strip()
-            except:
+            except (ValueError, IndexError):
                 what = i[4].strip()
             res.append("[%s %s] <%s> %s" % (dmy(float(i[1])), \
 hourmin(float(i[1])), i[2], what))
@@ -614,7 +632,7 @@ def handle_logsearch(bot, ievent):
 cmnds.add('log-search', handle_logsearch, ['USER', 'WEB', 'ANON'], speed=3)
 examples.add('log-search', 'log-search [<nrtimes>] <txt> .. search the log \
 from the beginning', '1) log-search http 2) log-search 10 http')
-aliases.data['search'] = 'log-search'
+aliasdel('search')
 
 
 def handle_loglast(bot, ievent):
@@ -665,7 +683,7 @@ def handle_seen(bot, ievent):
         return
     try:
         nick = ievent.args[0]
-    except:
+    except IndexError:
         ievent.missing('<nick>')
         return
     result = logs.seen(ievent.channel, nick)
@@ -677,11 +695,41 @@ def handle_seen(bot, ievent):
             what = result[4][6:]
         else:
             what = result[4]
-        ievent.reply("%s said: %s .. %s ago on %s" % \
-(result[2], what, elapsedstring(tdiff), result[0]))
+        ievent.reply("%s said: %s .. %s ago on %s (%s)" % \
+(result[2], what, elapsedstring(tdiff), ievent.channel, result[0]))
     else:
         ievent.reply("no %s in %s log" % (nick, ievent.channel))
 
 cmnds.add('seen', handle_seen, ['USER', 'WEB', 'ANON'], speed=3)
 examples.add('seen', 'seen <nick> .. show last logged line of <nick>', \
 'seen dunker')
+
+def handle_logtime(bot, ievent):
+    """ show log from a certain time """
+    if not logs:
+        ievent.reply('log plugin is not enabled')
+        return
+    if ievent.channel not in logs.loglist:
+        ievent.reply('logging is not enabled in %s' % ievent.channel)
+        return
+    fromtime = strtotime(ievent.rest)
+    if not fromtime:
+        ievent.reply("can't detect time")
+        return
+    result = logs.fromtimewithbot(ievent.channel, fromtime)
+    if result:
+        username = users.getname(ievent.userhost)
+        res = []
+        for i in result:
+            if i[2] == 'bot':
+                txt = i[4]
+            else:
+                nr = i[4].find(' ')
+                txt = i[4][nr:].strip()
+            res.append("[%s] <%s> %s" % (hourmin(float(i[1])), i[2], txt))
+        ievent.reply(res)
+        return
+    ievent.reply('no data found')
+    
+cmnds.add('log-time', handle_logtime, ['USER', 'WEB', 'ANON'])
+examples.add('log-time', 'show log since given time', 'log-time 21:00')
