@@ -22,8 +22,12 @@ def handle_mono(bot, ievent):
     except IndexError:
         nick = ievent.nick.lower()
     for i in bot.backlog[::-1]:
+        if i.cmnd != 'PRIVMSG':
+            continue
         if not i.nick:
             continue
+        if i.usercmnd:
+            continue
         if skip and i.nick.lower() != nick:
             continue
         else:
