@@ -7,6 +7,9 @@
 __copyright__ = 'this file is in the public domain'
 
 from gozerbot.callbacks import callbacks
+from gozerbot.plughelp import plughelp
+
+plughelp.add('nickcapture', 'nickcapture takes a nick back if a user quits')
 
 def ncaptest(bot, ievent):
     """ test if user is splitted """
