@@ -2,15 +2,19 @@
 #
 #
 
-""" used in a pipeline .. grep elements """
+""" used in a pipeline .. reverse grep elements """
 
 __copyright__ = 'this file is in the public domain'
 
 from gozerbot.commands import cmnds
 from gozerbot.generic import waitforqueue
+from gozerbot.plughelp import plughelp
 import getopt, re
 
+plughelp.add('not', 'the not command is a negative grep used in pipelines')
+
 def handle_not(bot, ievent):
+    """ negative grep """
     if not ievent.inqueue:
         ievent.reply('use not in a pipeline')
         return
