@@ -7,7 +7,7 @@
 __copyright__ = 'this file is in the public domain'
 
 from gozerbot.persist import Persist
-from gozerbot.generic import geturl, handle_exception, rlog
+from gozerbot.generic import geturl, handle_exception, rlog, strippedtxt
 from gozerbot.rsslist import rsslist
 from gozerbot.statdict import Statdict
 from gozerbot.fleet import fleet
@@ -15,17 +15,19 @@ from gozerbot.commands import cmnds
 from gozerbot.examples import examples
 from gozerbot.datadir import datadir
 from gozerbot.dol import Dol
-from xml.sax.handler import ContentHandler
 from gozerbot.plughelp import plughelp
 import gozerbot.thr as thr
-import xml.sax, re, time, os, types
+import time, os, types
+
+__gendocfirst__ = ['rss-add', ]
 
 plughelp.add('rss', 'manage rss feeds')
 
 savelist = []
 
 def txtindicts(result, d):
-    for i,j in d.iteritems():
+    """ return lowlevel values in (nested) dicts """
+    for j in d.values():
         if type(j) == types.DictType:
             txtindicts(result, j) 
         else:
@@ -64,6 +66,7 @@ class Rssdict(Persist):
             self.results = Dol()
 
     def size(self):
+        """ return number of rss entries """
         return len(self.data)
 
     def add(self, name, url):
@@ -100,7 +103,7 @@ class Rssdict(Persist):
         if urlresult == None:
             return []
         try:
-            result = rsslist(urlresult)
+            result = rsslist(strippedtxt(urlresult))
         except Exception, ex:
             handle_exception()
             rlog(10, 'rss', "can't parse %s feed" % rssitem.name)
@@ -302,6 +305,7 @@ def init():
     return 1
 
 def size():
+    """ return number of watched rss entries """
     return watcher.size()
 
 def shutdown():
@@ -320,8 +324,8 @@ def handle_rssadd(bot, ievent):
     ievent.reply('rss item added')
 
 cmnds.add('rss-add', handle_rssadd, ['RSS', 'OPER'])
-examples.add('rss-add', 'rss-add <name> <url> to the rsswatcher','rss-add \
-slashdot http://slashdot.org/slashdot.xml')
+examples.add('rss-add', 'rss-add <name> <url> to the rsswatcher', 'rss-add \
+gozerbot http://gozerbot.org/hg/gozerbot/?cmd=changelog;style=rss')
 
 def handle_rssdel(bot, ievent):
     """ rss-del <name> .. delete a rss item """
@@ -338,7 +342,7 @@ def handle_rssdel(bot, ievent):
 
 cmnds.add('rss-del', handle_rssdel, ['RSS', 'OPER'])
 examples.add('rss-del', 'rss-del <name> .. remove <name> from the \
-rsswatcher', 'rss-del slashdot')
+rsswatcher', 'rss-del mekker')
 
 def handle_rsswatch(bot, ievent):
     """ rss-watch <name> .. start watcher thread """
@@ -373,7 +377,7 @@ def handle_rsswatch(bot, ievent):
 
 cmnds.add('rss-watch', handle_rsswatch, ['RSS', 'OPER'])
 examples.add('rss-watch', 'rss-watch <name> [seconds to sleep] .. go \
-watching <name>', '1) rss-watch slashdot 2) rss-watch slashdot 600')
+watching <name>', '1) rss-watch gozerbot 2) rss-watch gozerbot 600')
 
 def handle_rsschannels(bot, ievent):
     """ rss-channels <name> .. show channels of rss feed """
@@ -389,11 +393,14 @@ def handle_rsschannels(bot, ievent):
     if not rssitem.watchchannels:
         ievent.reply('%s is not in watch mode' % name)
         return
-    ievent.reply("channels of %s" % name, rssitem.watchchannels, dot=True)
+    result = []
+    for i in rssitem.watchchannels:
+        result.append(str(i))
+    ievent.reply("channels of %s" % name, result, dot=True)
 
 cmnds.add('rss-channels', handle_rsschannels, ['RSS', 'OPER'])
 examples.add('rss-channels', 'rss-channels <name> .. show channels', \
-'rss-channels slashdot')
+'rss-channels gozerbot')
 
 def handle_rssaddchannel(bot, ievent):
     """ rss-addchannel <name> [<botname>] <channel> .. add a channel to \
@@ -431,7 +438,7 @@ def handle_rssaddchannel(bot, ievent):
 cmnds.add('rss-addchannel', handle_rssaddchannel, ['RSS', 'OPER'])
 examples.add('rss-addchannel', 'rss-addchannel <name> [<botname>] <channel> \
 ..add <channel> or <botname> <channel> to watchchannels of <name>', \
-'1) rss-addchannel slashdot #dunkbots 2) rss-addchannel slashdot main \
+'1) rss-addchannel gozerbot #dunkbots 2) rss-addchannel gozerbot main \
 #dunkbots')
 
 def handle_rssdelchannel(bot, ievent):
@@ -472,7 +479,7 @@ def handle_rssdelchannel(bot, ievent):
 cmnds.add('rss-delchannel', handle_rssdelchannel, ['RSS', 'OPER'])
 examples.add('rss-delchannel', 'rss-delchannel <name> [<botname>] \
 <channel> .. delete <channel> or <botname> <channel> from watchchannels of \
-<name>', '1) rss-delchannel slashdot #dunkbots 2) rss-delchannel slashdot \
+<name>', '1) rss-delchannel gozerbot #dunkbots 2) rss-delchannel gozerbot \
 main #dunkbots')
 
 def handle_rssstopwatch(bot, ievent):
@@ -498,7 +505,7 @@ ievent.channel))
 
 cmnds.add('rss-stopwatch', handle_rssstopwatch, ['RSS', 'OPER'])
 examples.add('rss-stopwatch', 'rss-stopwatch <name> .. stop polling <name>', \
-'rss-stopwatch slashdot')
+'rss-stopwatch gozerbot')
 
 def handle_rsssleeptime(bot, ievent):
     """ rss-sleeptime <name> .. get sleeptime of rss item """
@@ -519,7 +526,7 @@ str(rssitem.sleeptime)))
 
 cmnds.add('rss-sleeptime', handle_rsssleeptime, ['RSS', 'OPER'])
 examples.add('rss-sleeptime', 'rss-sleeptime <name> .. get sleeping time \
-for <name>', 'rss-sleeptime slashdot')
+for <name>', 'rss-sleeptime gozerbot')
 
 def handle_rsssetsleeptime(bot, ievent):
     """ rss-setsleeptime <name> <seconds> .. set sleeptime of rss item """
@@ -546,7 +553,7 @@ def handle_rsssetsleeptime(bot, ievent):
 
 cmnds.add('rss-setsleeptime', handle_rsssetsleeptime, ['RSS', 'OPER'])
 examples.add('rss-setsleeptime', 'rss-setsleeptime <name> <seconds> .. set \
-sleeping time for <name> .. min 60 sec', 'rss-setsleeptime slashdot 600')
+sleeping time for <name> .. min 60 sec', 'rss-setsleeptime gozerbot 600')
 
 def handle_rssget(bot, ievent):
     """ rss-get <name> .. fetch rss data """
@@ -581,7 +588,7 @@ def handle_rssget(bot, ievent):
 
 cmnds.add('rss-get', handle_rssget, ['RSS', 'USER', 'ANON'])
 examples.add('rss-get', 'rss-get <name> .. get data from <name>', \
-'rss-get slashdot')
+'rss-get gozerbot')
 
 def handle_rssrunning(bot, ievent):
     """ rss-running .. show which watchers are running """
@@ -620,7 +627,7 @@ def handle_rssurl(bot, ievent):
 
 cmnds.add('rss-url', handle_rssurl, ['RSS', 'USER', 'ANON'])
 examples.add('rss-url', 'rss-url <name> .. get url from rssitem with \
-<name>', 'rss-url slashdot')
+<name>', 'rss-url gozerbot')
 
 def handle_rssadditemslist(bot, ievent):
     """ rss-additemslist <name> <item> .. add item to itemslist of rss item """
@@ -643,7 +650,7 @@ def handle_rssadditemslist(bot, ievent):
 
 cmnds.add('rss-additemslist', handle_rssadditemslist, ['RSS', 'OPER'])
 examples.add('rss-additemslist', 'rss-additemslist <name> <item> .. add to \
-itemslist of <name> ', 'rss-additemslist slashdot url')
+itemslist of <name> ', 'rss-additemslist gozerbot url')
 
 def handle_rssdelitemslist(bot, ievent):
     """ rss-delitemslist <name> <item> .. delete item from itemslist """
@@ -665,7 +672,7 @@ def handle_rssdelitemslist(bot, ievent):
 
 cmnds.add('rss-delitemslist', handle_rssdelitemslist, ['RSS', 'OPER'])
 examples.add('rss-delitemslist', 'rss-delitemslist <name> <item> .. \
-delete from itemslist of <name> ', 'rss-delitemslist slashdot url')
+delete from itemslist of <name> ', 'rss-delitemslist gozerbot url')
 
 def handle_rssitemslist(bot, ievent):
     """ rss-itemslist <name> .. show itemslist of rss item """
@@ -678,11 +685,14 @@ def handle_rssitemslist(bot, ievent):
     if rssitem == None:
         ievent.reply("we don't have a %s rss item" % name)
         return
-    ievent.reply("itemslist of %s: " % name, rssitem.itemslist, dot=True)
+    if rssitem.itemslist:
+        ievent.reply("itemslist of %s: " % name, rssitem.itemslist, dot=True)
+    else:
+        ievent.reply('%s had no itemslist set' % name)
 
 cmnds.add('rss-itemslist', handle_rssitemslist, ['RSS', 'OPER'])
 examples.add('rss-itemslist', 'rss-itemslist <name> .. get itemslist of \
-<name> ', 'rss-itemslist slashdot')
+<name> ', 'rss-itemslist gozerbot')
 
 def handle_rssscan(bot, ievent):
     """ rss-scan <name> .. scan rss item for used xml items """
@@ -702,7 +712,7 @@ def handle_rssscan(bot, ievent):
 
 cmnds.add('rss-scan', handle_rssscan, ['RSS', 'OPER'])
 examples.add('rss-scan', 'rss-scan <name> .. get items of <name> ', \
-'rss-scan slashdot')
+'rss-scan gozerbot')
 
 def handle_rsssync(bot, ievent):
     """ rss-sync <name> .. sync rss item data """
@@ -720,7 +730,7 @@ def handle_rsssync(bot, ievent):
 
 cmnds.add('rss-sync', handle_rsssync, ['RSS', 'OPER'])
 examples.add('rss-sync', 'rss-sync <name> .. sync data of <name>', \
-'rss-sync slashdot')
+'rss-sync gozerbot')
 
 def handle_rssfeeds(bot, ievent):
     """ rss-feeds <channel> .. show what feeds are running in a channel """
