@@ -2,15 +2,20 @@
 #
 #
 
+""" do a timing of a command """
+
 __copyright__ = 'this file is in the public domain'
 
 from gozerbot.commands import cmnds
-from gozerbot.redispatcher import rebefore
 from gozerbot.examples import examples
 from gozerbot.plugins import plugins
+from gozerbot.plughelp import plughelp
 import time
 
+plughelp.add('timer', 'do a timing of a command')
+
 def handle_timer(bot, ievent):
+    """ do a timing of a command """
     if not ievent.rest:
         ievent.reply('<cmnd>')
         return
