@@ -10,17 +10,11 @@ from gozerbot.generic import getwho, stripident
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
 from gozerbot.users import users
-from gozerbot.aliases import aliases
+from gozerbot.aliases import aliases, aliasdel
 from gozerbot.plughelp import plughelp
-from gozerbot.config import config
 
 plughelp.add('user', 'manage users')
 
-def handle_showuserhosts(bot, ievent):
-    ievent.reply("%s %s" % (str(users.userhosts), str(users.masks)))
-
-cmnds.add('user-showuserhosts', handle_showuserhosts, 'OPER')
-
 def handle_getuserperm(bot, ievent):
     """ user-allperm <perm> .. list all users with permission <perm> """
     try:
@@ -114,6 +108,14 @@ def handle_merge(bot, ievent):
         ievent.missing('<name> <nick>')
         return  
     name, nick = ievent.args
+    name = name.lower()
+    if name == 'owner' and ievent.userhost != bot.owner:
+         ievent.reply('only owneruserhost can merge with owner user')
+         return 
+    if users.gotperm(name, 'OPER') and not users.allowed(ievent.userhost, \
+'OPER'):
+        ievent.reply("only OPER perm can merge with OPER user")
+        return
     if not users.exist(name):
         ievent.reply("we have no user %s" % name)
         return
@@ -131,7 +133,7 @@ def handle_merge(bot, ievent):
     else:
         ievent.reply('merge failed')
 
-cmnds.add('user-merge', handle_merge, 'OPER')
+cmnds.add('user-merge', handle_merge, ['OPER', 'MEET'])
 examples.add('user-merge', 'user-merge <name> <nick> .. merge record with \
 <name> with userhost from <nick>', 'merge bart dunker')
 aliases.data['merge'] = 'user-merge'
@@ -299,7 +301,7 @@ def handle_delperm(bot, ievent):
 
 cmnds.add('user-delperm', handle_delperm, 'OPER')
 examples.add('user-delperm', 'user-delperm <name> <perm> .. delete from user \
-<name> permission <perm>', 'user-delperms dunker rss')
+<name> permission <perm>', 'user-delperm dunker rss')
 
 def handle_addpermall(bot, ievent):
     """ user-addpermall <perm> .. add permission to all users """
@@ -318,7 +320,7 @@ def handle_addpermall(bot, ievent):
 
 cmnds.add('user-addpermall', handle_addpermall, 'OPER')
 examples.add('user-addpermall', 'user-addpermall <perm> .. add <permission> to \
-all users', 'addpermsall USER')
+all users', 'user-addpermall USER')
 
 def handle_delpermall(bot, ievent):
     """ user-delpermall <perm> .. delete permission from all users """
@@ -341,7 +343,7 @@ def handle_delpermall(bot, ievent):
 
 cmnds.add('user-delpermall', handle_delpermall, 'OPER')
 examples.add('user-delpermall', 'user-delpermall <perm> .. delete <permission> \
-from all users', 'delpermsall BLA')
+from all users', 'user-delpersall BLA')
 
 def handle_addstatus(bot, ievent):
     """ user-addstatus <name> <status> .. add status of name """
@@ -559,7 +561,7 @@ def handle_setemail(bot, ievent):
 
 cmnds.add('user-setemail', handle_setemail, 'OPER')
 examples.add('user-setemail', 'user-setemail <name> <email>.. set email of \
-user <name>', 'user-setemail dunker bart@r8.cg.nu')
+user <name>', 'user-setemail dunker bart@gozerbot.org')
 aliases.data['setemail'] = 'user-setemail'
 
 def handle_email(bot, ievent):
@@ -632,7 +634,7 @@ def handle_addpermit(bot, ievent):
         <name> """
     try:
         who, what = ievent.args
-    except:
+    except ValueError:
         ievent.missing("<name> <what>")
         return
     whouser = users.byname(who)
@@ -654,7 +656,7 @@ cmnds.add('user-addpermit', handle_addpermit, 'USER')
 examples.add('user-addpermit', 'user-addpermit <nick> <what> .. permit \
 nick access to <what> .. use setperms to add permissions', \
 'user-addpermit dunker todo')
-aliases.data['allow'] = 'user-addpermit'
+aliasdel('allow')
 
 def handle_permit(bot, ievent):
     """ user-permit .. get permit list of user giving the command """
@@ -665,9 +667,12 @@ what permits you have")
         return
     user = users.getuser(ievent.userhost)
     if user.permit:
-        ievent.reply("you permit the following: ", user.permit, dot=True)
+        result = []
+        for i in user.permit:
+            result.append(str(i))
+        ievent.reply("you permit the following: ", result, dot=True)
     else:
-        ievent.reply("you don't have any permits")
+        ievent.reply("you don't have any permits set")
 
 cmnds.add('user-permit', handle_permit, 'USER')
 examples.add('user-permit', 'show permit of user giving the command', \
@@ -700,20 +705,21 @@ def handle_userdelpermit(bot, ievent):
 cmnds.add('user-delpermit', handle_userdelpermit, 'USER')
 examples.add('user-delpermit', 'user-delpermit <name> <permit>', \
 'user-delpermit dunker todo')
-aliases.data['deny'] = 'user-delpermit'
+aliasdel('deny')
 
 def handle_usersearch(bot, ievent):
+    """ search user with matching userhost """
     try:
         what = ievent.args[0]
     except IndexError:
-       ievent.missing('<what>')
-       return
+        ievent.missing('<what>')
+        return
     got = []
     for i in users.data:
-       for j in i.userhosts:
-           if what in j:
-               name = users.getname(j) 
-               got.append((name, j))
+        for j in i.userhosts:
+            if what in j:
+                name = users.getname(j) 
+                got.append((name, j))
     if got:
         result = []
         for i in got:
@@ -723,4 +729,5 @@ def handle_usersearch(bot, ievent):
         ievent.reply('no userhost matching %s found' % what)
 
 cmnds.add('user-search', handle_usersearch, 'OPER')
-examples.add('user-search', 'search for matching userhosts', 'user-search r8')
+examples.add('user-search', 'search for matching userhosts', 'user-search \
+gozerbot')
