@@ -2,6 +2,8 @@
 #
 #
 
+""" dispatch web request onto the plugins dispatcher """
+
 __copyright__ = 'this file is in the public domain'
 
 from gozerbot.generic import waitforqueue
@@ -9,23 +11,19 @@ from gozerbot.fleet import fleet
 from gozerbot.ircevent import Ircevent
 from gozerbot.plugins import plugins
 from gozerbot.thr import start_new_thread
-from gozerbot.config import config
 from gozerplugs.plugs.webserver import httpd
-from cgi import escape
 from urllib import unquote_plus
-import Queue, time
+import Queue
 
 def handle_dispatch(event):
+    """ dispatch web request """
     input = unquote_plus(event.path)
-    if config['jabberenable']:
-        bot = fleet.byname('jabbermain')
-    else:
-        bot = fleet.byname('main')
+    bot = fleet.getmainbot()
     ievent = Ircevent()
     try:
         what = input.split('?', 1)[1]
     except IndexError:
-        return ["dispatch what ?",]
+        return ["dispatch what ?", ]
     if what.startswith("command="):
         what = what[8:]
     ievent.txt = what
